summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/lib/Bcfg2/Server/FileMonitor/Fam.py10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/lib/Bcfg2/Server/FileMonitor/Fam.py b/src/lib/Bcfg2/Server/FileMonitor/Fam.py
index 46a2f88f8..253bb2801 100644
--- a/src/lib/Bcfg2/Server/FileMonitor/Fam.py
+++ b/src/lib/Bcfg2/Server/FileMonitor/Fam.py
@@ -1,5 +1,5 @@
""" File monitor backend with support for the `File Alteration Monitor
-<http://oss.sgi.com/projects/fam/>`_."""
+<http://oss.sgi.com/projects/fam/>`_. The FAM backend is deprecated. """
import os
import _fam
@@ -12,9 +12,9 @@ LOGGER = logging.getLogger(__name__)
class Fam(FileMonitor):
- """ File monitor backend with support for the `File Alteration
- Monitor <http://oss.sgi.com/projects/fam/>`_ (also abbreviated
- "FAM")."""
+ """ **Deprecated** file monitor backend with support for the `File
+ Alteration Monitor <http://oss.sgi.com/projects/fam/>`_ (also
+ abbreviated "FAM")."""
#: FAM is the worst actual monitor backend, so give it a low
#: priority.
@@ -24,6 +24,8 @@ class Fam(FileMonitor):
FileMonitor.__init__(self, ignore=ignore, debug=debug)
self.filemonitor = _fam.open()
self.users = {}
+ LOGGER.warning("The Fam file monitor backend is deprecated. Please "
+ "switch to a supported file monitor.")
__init__.__doc__ = FileMonitor.__init__.__doc__
def fileno(self):